==> gatsby-core-theme-30.0.30.tgz: package/src/components/app-ssr.js <==
/* eslint-disable react/prop-types */
/* eslint-disable react/forbid-prop-types */
import React, { useEffect, useState } from 'react';
import PropTypes from 'prop-types';
import { globalHistory } from '@reach/router';
import MainProvider from '~context/MainProvider';
import Body from '~pages/body';
import HeadData from '~organisms/head';
import { getAPIData } from '~helpers/server-data';

const AppSSR = ({ pageContext, serverData }) => {
  const { translations = {}, isPreview } = pageContext;
  const [previewContext, setPreviewContext] = useState({});
  const [isLoading, setIsLoading] = useState({});
  async function getData(searchParams, staticPath = null) {
    const { getPreview } = await import('~helpers/api');
    getPreview(
      pageContext.siteName,
      !staticPath ? searchParams.get('path') || '/' : staticPath,
      pageContext
    ).then((previewResponse) => {
      if (previewResponse.page) {
        // siteInfo and siteSchema are added to page for schemaGenerator()
        previewResponse.page.siteInfo = pageContext.siteInfo;
        previewResponse.page.siteSchema = pageContext.siteSchema;
      }
      setPreviewContext(previewResponse);
      setIsLoading(false);
    });
  }

  useEffect(() => {
    if (isPreview) {
      setIsLoading(true);
      const searchParams =
        typeof window !== 'undefined' ? new URLSearchParams(window.location.search) : null;
      if (!searchParams.get('path')) {
        window.location = `${window.location.origin}/preview?path=/`;
      }
      getData(searchParams);
      globalHistory.listen(({ location }) => {
        setIsLoading(true);

        getData(null, location.search.replace('?path=', ''));
      });
    }
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);

  if (isPreview) {
    if (isLoading) {
      return 'Loading...';
    }
  }

  return (
    <>
      <MainProvider value={{ translations }}>
        <Body pageContext={isPreview ? previewContext : pageContext} serverData={serverData} />
      </MainProvider>
    </>
  );
};

export const Head = ({ pageContext }) => (
  <HeadData page={pageContext.page} siteInfo={pageContext.siteInfo} />
);

AppSSR.propTypes = {
  pageContext: PropTypes.shape({
    siteName: PropTypes.string,
    isTracker: PropTypes.bool,
    isPreview: PropTypes.bool,
    page: PropTypes.shape({
      id: PropTypes.number,
      path: PropTypes.string,
    }),
    translations: PropTypes.object,
    siteInfo: PropTypes.shape({
      robots_txt: PropTypes.string,
      site_logo: PropTypes.string,
      site_name: PropTypes.string,
    }),
    siteSchema: PropTypes.shape({
      site_name: PropTypes.string,
    }),
  }),
  serverData: PropTypes.shape({
    props: PropTypes.string,
  }),
};

export async function getServerData({ pageContext, url }) {
  let res = '';
  res = await getAPIData(pageContext.page, url);
  return res;
}
export default AppSSR;

==> gatsby-core-theme-31.0.2.tgz: package/src/components/app-ssr.js <==
/* eslint-disable react/prop-types */
/* eslint-disable react/forbid-prop-types */
import React, { useEffect, useState } from 'react';
import PropTypes from 'prop-types';
import { globalHistory } from '@reach/router';
import MainProvider from '~context/MainProvider';
import Body from '~pages/body';
import HeadData from '~organisms/head';
import { getAPIData } from '~helpers/server-data';

const AppSSR = ({ pageContext, serverData }) => {
  const { translations = {}, isPreview } = pageContext;
  const [previewContext, setPreviewContext] = useState({});
  const [isLoading, setIsLoading] = useState({});
  async function getData(searchParams, staticPath = null) {
    const { getPreview } = await import('~helpers/api');
    getPreview(
      pageContext.siteName,
      !staticPath ? searchParams.get('path') || '/' : staticPath,
      pageContext
    ).then((previewResponse) => {
      if (previewResponse.page) {
        // siteInfo and siteSchema are added to page for schemaGenerator()
        previewResponse.page.siteInfo = pageContext.siteInfo;
        previewResponse.page.siteSchema = pageContext.siteSchema;
      }
      setPreviewContext(previewResponse);
      setIsLoading(false);
    });
  }

  useEffect(() => {
    if (isPreview) {
      setIsLoading(true);
      const searchParams =
        typeof window !== 'undefined' ? new URLSearchParams(window.location.search) : null;
      if (!searchParams.get('path')) {
        window.location = `${window.location.origin}/preview?path=/`;
      }
      getData(searchParams);
      globalHistory.listen(({ location }) => {
        setIsLoading(true);

        getData(null, location.search.replace('?path=', ''));
      });
    }
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);

  if (isPreview) {
    if (isLoading) {
      return 'Loading...';
    }
  }

  return (
    <>
      <MainProvider value={{ translations }}>
        <Body pageContext={isPreview ? previewContext : pageContext} serverData={serverData} />
      </MainProvider>
    </>
  );
};

export const Head = ({ pageContext }) => (
  <HeadData page={pageContext.page} siteInfo={pageContext.siteInfo} />
);

AppSSR.propTypes = {
  pageContext: PropTypes.shape({
    siteName: PropTypes.string,
    isTracker: PropTypes.bool,
    isPreview: PropTypes.bool,
    page: PropTypes.shape({
      id: PropTypes.number,
      path: PropTypes.string,
    }),
    translations: PropTypes.object,
    siteInfo: PropTypes.shape({
      robots_txt: PropTypes.string,
      site_logo: PropTypes.string,
      site_name: PropTypes.string,
    }),
    siteSchema: PropTypes.shape({
      site_name: PropTypes.string,
    }),
  }),
  serverData: PropTypes.any,
};

export async function getServerData({ pageContext, url }) {
  let res = '';
  res = await getAPIData(pageContext.page, url);
  return res;
}
export default AppSSR;
